scinumtools.stats package
=========================

Submodules
----------

scinumtools.stats.StopwatchClass module
---------------------------------------

.. automodule:: scinumtools.stats.StopwatchClass
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: scinumtools.stats
   :members:
   :undoc-members:
   :show-inheritance:
